#
# spec file for package twinkle
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           twinkle
Version:        1.10.3
Release:        4.1
Summary:        A SIP Soft Phone
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/SIP/Clients
URL:            https://github.com/LubosD/twinkle
Source:         https://github.com/LubosD/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:         Add-support-for-the-new-bcg729-API-introduced-in-ver.patch
BuildRequires:  alsa-devel
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  file-devel
BuildRequires:  flex
BuildRequires:  ilbc-devel
BuildRequires:  libgsm-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qttools-devel
BuildRequires:  libsndfile-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(commoncpp)
BuildRequires:  pkgconfig(libbcg729)
BuildRequires:  pkgconfig(libccrtp)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description
Twinkle is a SIP-based soft phone for making telephone calls over IP
networks.

%prep
%autosetup -p1

%build
%cmake \
  -DWITH_ZRTP=OFF \
  -DWITH_SPEEX=ON \
  -DWITH_ILBC=ON \
  -DWITH_GSM=ON \
  -DWITH_G729=ON \
  -DWITH_ALSA=ON \
  -DWITH_QT5=ON
%make_build

%install
%cmake_install
install -d 755 %{buildroot}%{_datadir}/pixmaps
%suse_update_desktop_file -c twinkle Twinkle "SIP VoIP Phone" twinkle twinkle Network Telephony
%fdupes %{buildroot}%{_prefix}

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%doc AUTHORS README.md
%license COPYING
%{_bindir}/twinkle
%{_bindir}/twinkle-console
%{_datadir}/%{name}
%{_datadir}/pixmaps/twinkle.png
%{_datadir}/icons/hicolor
%{_datadir}/applications/twinkle.desktop
%{_mandir}/man1/twinkle.1%{?ext_man}

%changelog
* Thu Jul 11 2024 Dirk Müller <dmueller@suse.com>
- update home page link to a working page
- remove ZRTP support (bdo#797554, bsc#1219884)
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Remove BuildRequire on xorg-x11-devel, there are no inclusions
  of X11/ header files.
* Wed Dec 28 2022 Dirk Müller <dmueller@suse.com>
- update to 1.10.3:
  * Replace manual URL.
* Fri Nov  8 2019 Michal Kubecek <mkubecek@suse.cz>
- one more twinkle -> %%{name} cleanup in specfile
* Fri Nov  8 2019 Michal Kubecek <mkubecek@suse.cz>
- enable G.729 support (with libbcg729)
  * add Add-support-for-the-new-bcg729-API-introduced-in-ver.patch
    (compatibility with libbcg729 >= 1.0.2)
- specfile cleanup
  * rename v1.10.2.tar.gz -> twinkle-1.10.2.tar.gz
  * adjust Source URL
  * drop compatibility tweaks for openSUSE < 15.0 (those didn't
    build after dropping gcc 4.8 patches anyway)
* Mon Jul  8 2019 Joop Boonen <joop.boonen@opensuse.org>
- update to version 1.10.2
  * Fix sound not working with ALSA 1.1.7.
  * Translation updates.
  * Various bug fixes.
- patch Include-QRegExpValidator-explicitly.patch is included in the code
- removed patches Revert-Build-fix-for-a-probably-broken-std-match_res.patch and
  Revert-Replaced-Boost-regex-dependency-with-C-11-reg.patch as gcc 4.8 is not
  used any more in a supported openSUSE version
* Wed Jun  6 2018 mkubecek@suse.cz
- add Include-QRegExpValidator-explicitly.patch
  fix build against Qt 5.11
- use %%license for license file
* Mon Oct 24 2016 mkubecek@suse.cz
- update to version 1.10.1
  * stability fixes (calling Qt methods from wrong thread)
  * set PA role to phone to pause music playback automatically
  * French translation updates
  * remove obsolete commoncpp2 dependency
- DTMF-event-type-cleanup.patch:
  drop (merged into upstream)
- Revert-Replaced-Boost-regex-dependency-with-C-11-reg.patch:
  refresh
* Wed Aug 31 2016 dimstar@opensuse.org
- Drop bogus pkgconfig(Qt5Declarative) BuildRequires: the build
  system does not check for this.
* Fri May 20 2016 mkubecek@suse.cz
- update to current git snapshot (commit 4627d49d5e2d)
  * fix build against Qt 5.6
  * drop Qt4 compatibility
  * fix build against ucommon 7.0
  * allow build against system libgsm
  * crash fixes
  * digest authentication case sensitivity fix
  * other minor fixes (UI, spelling, translations)
- build against system libgsm
- fix-build-with-ucommon-7.0.patch:
  deleted (merged into upstream)
- twinkle-no-return-in-nonvoid-function.patch:
  replace by DTMF-event-type-cleanup.patch (more complex, intended
  for upstream)
- Revert-Replaced-Boost-regex-dependency-with-C-11-reg.patch:
  refresh
* Thu Jan  7 2016 mkubecek@suse.cz
- fix-build-with-ucommon-7.0.patch:
  fix build with ucommon 7.0
- reorder patches so that the optional gcc 4.8 workaround comes
  after normal patches
* Thu Oct  8 2015 mpluskal@suse.com
- Use cmake macro
- Add twinkle-no-return-in-nonvoid-function.patch
- Use desktop file macros
* Tue Sep 29 2015 mkubecek@suse.cz
- fix Leap 42.1 build
  Leap 42.1 sets suse_version to 1315 but it already has ilbc-devel
  split out of the main package unlike 13.2. Add some more specfile
  hacks to fix the build. This version builds correctly on 13.1,
  13.2, Factory and Leap.
* Sat Jul 18 2015 mkubecek@suse.cz
- update to version 1.9.0
  * migration to Qt5 and cmake
  * added in-call OSD
  * remember window geometry and state
  * visual feedback when entering DTMF from keyboard
  * support past into DTMF window
  * remove boost dependency (if gcc >= 4.9)
  * eliminated some GUI freezes/stalls
- dependencies and build phase cleanup
- twinkle-ucommon.diff:
  removed (no longer needed)
- Revert-Build-fix-for-a-probably-broken-std-match_res.patch:
  Revert-Replaced-Boost-regex-dependency-with-C-11-reg.patch:
  use boost regex for gcc 4.8 distributions (std::regex is broken
  in gcc 4.8)
* Tue May 26 2015 lmuelle@suse.com
- Add ilbc as build time requirement again; (boo#707856)
* Thu Sep 26 2013 jengelh@inai.de
- Shift BuildRequires to explicitly use zrtpcpp2
- Remove redundant %%clean section
* Thu Jan 19 2012 anixx@opensuse.org
- remove use of a broken, deprecated macro
* Tue Sep 27 2011 coolo@suse.com
- fix build with newer ld
* Sat Aug 20 2011 Werner.Dittmann@t-online.de
- Fix BuildRequires to fetch the new libzrtpcpp2
* Sun Jul 24 2011 Werner.Dittmann@t-online.de
- add patch to modify Twinkle to use the new GNU uCommon/commoncpp libraries
- remove dependency to common C++ library
- merged the small non-void patch into the ucommon patch
* Mon Jun  6 2011 coolo@novell.com
- do not remove the original COPYING
* Mon Mar  8 2010 ro@suse.de
- fix compiler warning about no-return-in-nonvoid-function
* Thu Feb 26 2009 rbos@opensuse.org
- Integration with Diamondcard Worldwide Communication Service
  (worldwide calls to regular and cell phones and SMS).
- Show number of calls and total call duration in call history.
- Show message size while typing an instant message.
- Show "referred by" party for an incoming transferred call in systray popup.
- Option to allow call transfer while consultation call is still in progress.
- Improved lock file checking. No more stale lock files.
- Opening an IM attachment did not work anymore.
- Link with ncurses library
* Sat Jan 31 2009 rbos@opensuse.org
  * Update to 1.4.1
  * No sound when Twinkle is compiled without speex support.
  * Compiling without KDE sometimes failed (cannot find -lqt-mt).
  * Configure script did not correctly check for the readline-devel package.
  * The twinkle-return.patch is no longer needed, the patch is part of
  twinkle itself now.
* Mon Jan 26 2009 rbos@opensuse.org
  * Update to 1.4
  * Service route discovery during registration.
  * Codec preprocessing: automatic gain control, voice activation detection,
  noise reduction, acoustic echo cancellation (experimental).
  * Support tel-URI as destination address for a call or instant message.
  * User profile option to expand a telephone number to a tel-URI instead
  of a sip-URI.
  * Add descending q-value to contacts in 3XX responses for the redirection
  services.
  * AKAv1-MD5 authentication.
  * Command line editing, history, auto-completion.
  * Ignore wrong formatted domain-parameter in digest challenge.
  * Match tel-URI in incoming call to address book.
  * Determine RTP IP address for SDP answer from RTP IP address in SDP offer.
  * Show context menu's when pressing the right mouse button instead of
  after clicking.
  * Swedish translation
  * Resampled ringback tone from 8287 Hz to 8000 Hz
  * Text line edit in the message form looses focus after sending an IM.
  * Twinkle does not escape reserved symbols when dialing.
  * Deregister all function causes a crash.
  * Twinkle crashes at startup in CLI mode.
  * Twinkle may freeze when an ALSA error is detected when starting
  the ringback tone and the outgoing call gets answered very fast.
  * User profile editor did not allow spaces in a user name.
  RFC 3608 - Session Initiation Protocol (SIP) Extension Header Field
    for Service Route Discovery During Registration
* Tue Sep  9 2008 hvogel@suse.de
- Update to 1.3.2
  * gcc 4.3 fixes
  * Disable file attachment button in message window when destination
    address is not filled in
  * Updated russian translation
  * Send file attachment with instant message.
  * Show timestamp with instant messages.
  * Instant message composition indication (RFC 3994).
  * Persistent TCP connections with keep alive.
  * Do not try to send SIP messages larger than 64K via UDP.
  * Xsession support to restore Twinkle after system shutdown/startup.
  * Call snd_pcm_state to determine jitter buffer exhaustion (some ALSA
    implementations gave problems with the old method).
  * SDP parser allows SDP body without terminating CRLF.
  * SIP parser did not allow white space between header name and colon.
  * With "send in-dialog requests to proxy" enabled and transport
    mode set to "auto", in-dialog requests are wrongly sent via TCP.
  * Crash when a too large message is received.
  * Comparison of authentication parameters (e.g. algorithm) were case-sensitive.
    These comparisons must be case-insensitive.
  * SDP parser could not parse other media transports than RTP/AVP.
  * Twinkle sent 415 response instead of 200 OK on in-dialog INFO without body.
  * Twinkle responds with 513 Message too large on an incoming call.
  * ICMP error on STUN request causes Twinkle to crash.
  * Add received-parameter to Via header of an incoming request if it contains
    an empty rport parameter (RFC 3581)
  * Twinkle did not add Contact header and copy Record-Route header
    to 180 response.
* Tue May  6 2008 aj@suse.de
- Add missing return values.
* Wed Mar 12 2008 crrodriguez@suse.de
- update to version 1.2 [bnc#370032]
  SIP over TCP
- Automatic selection of IP address.
  * On a multi-homed machine you do not have to select an IP address/NIC
    anymore.
  * You can now start Twinkle when the network interface is down.
- Support for sending a q-value in a registration contact.
- Send DTMF on an early media stream.
- Choose auth over auth-int qop when server supports both for authentication.
  This avoids problems with SIP ALGs.
- Support tel-URI in From and To headers in incoming SIP messages.
- Print a log rotation message at end of log when a log file is full.
- Remove 20 character limit on profile names.
- Reject an incoming MESSAGE with 603 if max. sessions == 0
- Delivery notification when a 202 response is received on a MESSAGE.
* Fri Jan 18 2008 coolo@suse.de
- adding bison to buildrequires
* Thu Nov  8 2007 coolo@suse.de
- fix linking too
* Thu Nov  1 2007 coolo@suse.de
- fix compile, leaving the linking error to the experts
* Tue Oct 23 2007 mskibbe@suse.de
- Bug 327023 - twinkle-1.1-24.src.rpm. Translations broken.
  [was:Obsolete patches and german language file not up to date]
  o build with qt3 packages instead of qt4
* Tue Oct  9 2007 mskibbe@suse.de
- Bug 327023 - twinkle-1.1-24.src.rpm. Translations broken.
  [was:Obsolete patches and german language file not up to date]
* Fri Sep 28 2007 mskibbe@suse.de
- Bug 327023 - factory twinkle-1.1-20.src.rpm. Obsolete patches and
  german language file not up to date
* Thu Aug  2 2007 mskibbe@suse.de
- Update Twinkle (#296638)
- update to version 1.1 which includes
  o French translation
  o Instant Messaging
  o a lot of bugfixes
* Thu Mar 22 2007 mskibbe@suse.de
- add ilbc support by requirering the ilbc package
* Thu Feb 22 2007 mskibbe@suse.de
- add zrtp support
* Thu Feb 15 2007 mskibbe@suse.de
- update to version 1.0 which includes
  o Local address book
  o Message waiting indication (MWI)
  o Voice mail speed dial
  o Call transfer with consultation
  o Attended call transfer
  o User identity hiding
  o Multi language support
  o Send BYE when a CANCEL/2XX INVITE glare occurs.
  o When call release was not immediate due to network problems or protocol errors,
    the line would be locked for some time. Now Twinkle releases a call in the
    background immediately freeing the line for new calls.
  o Escape reserved symbols in a URI by their hex-notation (%%hex).
  o Changed key binding for Bye from F7 to ESC
  o When a lock file exists at startup, Twinkle asks if you want to override it
  o New command line options: --force, --sip-port, --rtp-port
  o Ring tone and speaker device list now also shows playback only devices
  o Microphone device list now also shows capture only devices
  o Validate audio device settings on startup, before making a call, before
    answering a call.
  o SIP_FROM_USER, SIP_FROM_HOST, SIP_TO_USER, SIP_TO_HOST variables for call scripts.
  o display_msg parameter added to incoming call script
  o User profile options to indicate which codec preference to follow
  o Twinkle now asks permission for an incoming REFER asynchronously. This
    prevents blocking of the transaction layer.
  o Highlight missed calls in call history
  o Support for G.726 ATM AAL2 codeword packing
  o replaces SIP extension (RFC 3891)
  o norefesub SIP extension (RFC 4488)
  o SIP parser supports IPv6 addresses in SIP URI's and Via headers
  o Support mid-call change of SSRC
  o Handling of SIGCHLD, SIGTERM and SIGINT on platforms implementing
    LinuxThreads instead of NPTL threading (e.g. sparc)
* Mon Jan 15 2007 mskibbe@suse.de
- Twinkle crashes once in a while (#229813)
- Twinkle: DTMF gets disabled (#229814)
- Twinkle: To/From/Subject labels are not cleared (#229816)
* Thu Oct 12 2006 mskibbe@suse.de
- update to version 0.9 which
  o Supports ZRTP and SRTP for secure voice communication
  o includes DTMF via SIP INFO
  o includes G.726 codec (16, 24, 32 and 48 kbps modes)
  o includes Option to hide display
  o Switch lines from system tray menu
  o Answer or reject a call from the KDE systray popup on incoming
    call
  o a lot of bugfixes
* Mon Jul 17 2006 mskibbe@suse.de
- fix compiler warnings (newline at end of line problem)
- work arround for bug #187369 "missing return statement"
* Fri Jul 14 2006 mskibbe@suse.de
- update to version 0.8.1 which
  o Removed iLBC source code
  o fix some bugs
  o Added missing includes to userprofile.ui and addressfinder.h
  o Configure has new --without-speex option
* Thu May 18 2006 hvogel@suse.de
- update to version 0.7.1
  * UTF-8 support to properly display non-ASCII characters
  * Speex support (narrow, wide and ultra wide band)
  * Support for dynamic payload numbers for audio codecs in SDP
  * New SIP protocol option: allow SDP change in INVITE responses
* Fri Jan 27 2006 hvogel@suse.de
- export QTDIR
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 hvogel@suse.de
- update to version 0.5
* Thu Oct 27 2005 kkaempf@suse.de
- needs commoncpp2 for build now.
* Tue Oct 25 2005 hvogel@suse.de
- update to version 0.3.2
* Mon Aug  1 2005 mmj@suse.de
- update to 0.2.1 [#83902]
* Mon May 30 2005 ro@suse.de
- rework neededforbuild
* Wed May 25 2005 hvogel@suse.de
- Initial package, Version 0.1
